pub struct RingSet(/* private fields */);Expand description
The Smallest Set of Smallest Rings for a molecule.
Each ring is stored as a sequence of AtomIdx values listed in ring order.
The first atom is not repeated at the end.
Implementations
Sourceimpl RingSet
impl RingSet
Sourcepub fn ring_count(&self) -> usize
pub fn ring_count(&self) -> usize
Number of rings in the SSSR.
Sourcepub fn contains_atom(&self, atom: AtomIdx) -> bool
pub fn contains_atom(&self, atom: AtomIdx) -> bool
Whether atom atom is a member of at least one ring.
Sourcepub fn atoms_in_ring_count(&self, atom: AtomIdx) -> usize
pub fn atoms_in_ring_count(&self, atom: AtomIdx) -> usize
Number of rings that atom atom belongs to.